#[non_exhaustive]pub enum ProxyProtocol {
Socks {
version: SocksVersion,
auth: SocksAuth,
addr: SocketAddr,
},
HttpConnect {
addr: SocketAddr,
credentials: Option<HttpConnectAuth>,
},
}Expand description
Information about what proxy protocol to use, and how to use it.
This type can be parsed from a URI string using the same format as curl’s proxy URL syntax (see https://curl.se/docs/url-syntax.html).
Supported formats:
-
socks4://ip:port- SOCKS4 proxy -
socks4://user@ip:port- SOCKS4 proxy with user ID -
socks4a://ip:port- SOCKS4a proxy (treated same as socks4) -
socks5://ip:port- SOCKS5 proxy without auth -
socks5://user:pass@ip:port- SOCKS5 proxy with username/password auth -
socks5://user@ip:port- SOCKS5 proxy with username only (empty password) -
socks5h://ip:port- SOCKS5 with remote hostname resolution (treated same as socks5) -
Hostnames for the proxy server itself are not supported (applies to all proxy types).
-
Credentials must be embedded in the URI; curl’s
-U user:passstyle is not supported. -
For
socks4://, passwords are not supported and will return an error. -
Special characters in credentials are percent-encoded using the
urlcrate’s userinfo encoding.
HTTP CONNECT:
Hostnames for the proxy server itself are not supported (only IP addresses).
http://ip:port- HTTP CONNECT proxy without authhttp://user:pass@ip:port- HTTP CONNECT proxy with Basic auth (RFC 7617)http://user@ip:port- HTTP CONNECT proxy with username only (empty password)
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Socks
Connect via SOCKS 4, SOCKS 4a, or SOCKS 5.
HttpConnect
Connect via HTTP CONNECT proxy.
Fields
addr: SocketAddrThe proxy server address
credentials: Option<HttpConnectAuth>Optional credentials for Basic auth (RFC 7617)
Implementations
Sourceimpl ProxyProtocol
impl ProxyProtocol
Sourcepub fn is_loopback(&self) -> bool
pub fn is_loopback(&self) -> bool
Check whether the proxy server address is on the loopback interface.
Sourceimpl ProxyProtocol
impl ProxyProtocol
Sourcepub fn socks_no_auth(version: SocksVersion, addr: SocketAddr) -> Self
pub fn socks_no_auth(version: SocksVersion, addr: SocketAddr) -> Self
Create a new SOCKS proxy configuration with no authentication