#[non_exhaustive]pub enum ProxyProtocolParseError {
UnsupportedScheme(String),
UnsupportedPassword(String),
InvalidAddress(String),
InvalidPort,
InvalidFormat(String),
}Expand description
Error parsing a proxy URI string
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedScheme(String)
Proxy URI has an unsupported or missing scheme.
UnsupportedPassword(String)
Proxy URI includes a password for a scheme that does not support it.
InvalidAddress(String)
Proxy URI had an invalid or unparsable address.
InvalidPort
Proxy URI is missing a port or has an invalid port.
InvalidFormat(String)
Proxy URI does not match the expected format.