open_channel_is_allowed

Function open_channel_is_allowed 

pub(crate) fn open_channel_is_allowed<C: AbstractChannel>(
    chan: &OpenEntry<C>,
    target: &(impl HasRelayIds + HasChanMethod),
) -> bool
Returns true if the open channel is allowed to be used for a new channel request to the target.