pending_channel_maybe_allowed

Function pending_channel_maybe_allowed 

pub(crate) fn pending_channel_maybe_allowed(
    chan: &PendingEntry,
    target: &(impl HasRelayIds + HasChanMethod),
) -> bool
Returns true if the pending channel could possibly be used for a new channel request to the target. You still need to verify the final built channel with open_channel_is_allowed before using it.