fn padding_parameters(
config: PaddingLevel,
netdir: &NetParamsExtract,
) -> Result<Option<Parameters>, Bug>Expand description
Given a NetDirExtract and whether we’re reducing padding, return a PaddingParameters
With PaddingLevel::None, or the consensus specifies no padding, will return None;
but does not account for other reasons why padding might be enabled/disabled.