fn remove_pending<C: AbstractChannel>(
channel_map: &mut ListByRelayIds<ChannelState<C>>,
handle: PendingChannelHandle,
)Expand description
Helper: remove the pending channel identified by handle from channel_map.
fn remove_pending<C: AbstractChannel>(
channel_map: &mut ListByRelayIds<ChannelState<C>>,
handle: PendingChannelHandle,
)Helper: remove the pending channel identified by handle from channel_map.