struct Inner<C: AbstractChannelFactory> {
builder: C,
channels: ListByRelayIds<ChannelState<C::Channel>>,
unauth_channels: Vec<Arc<C::Channel>>,
channels_params: ChannelParams,
config: ChannelConfig,
dormancy: Dormancy,
}Expand description
A map from channel id to channel state, plus necessary auxiliary state - inside lock
Fields
builder: CThe channel factory type that we store.
In this module we never use this as an AbstractChannelFactory: we just hand out clones of it when asked.
channels: ListByRelayIds<ChannelState<C::Channel>>A map from identity to channels, or to pending channel statuses.
unauth_channels: Vec<Arc<C::Channel>>A list of unauthenticated channels meaning they are client/bridge -> relay. We populate this list as a relay responder accepting incoming connections.
Notice here that ChannelState is NOT used because we don’t need a pending state of
unauthenticated channels (inbound client/bridge) because multiple channel from the same
peer can coexist. Furthermore, these channels are never looked up for normal relay
operations and so a pending state is not needed.
channels_params: ChannelParamsParameters for channels that we create, and that all existing channels are using
Will be updated by a background task, which also notifies all existing
Open channels via channels.
(Must be protected by the same lock as channels, or a channel might be
created using being-replaced parameters, but not get an update.)
config: ChannelConfigThe configuration (from the config file or API caller)
dormancy: DormancyDormancy
The last dormancy information we have been told about and passed on to our channels.
Updated via MgrState::set_dormancy and hence MgrState::reconfigure_general,
which then uses it to calculate how to reconfigure the channels.