pub(crate) struct MgrState<C: AbstractChannelFactory> {
inner: Mutex<Inner<C>>,
}Expand description
All mutable state held by an AbstractChannelMgr.
One reason that this is an isolated type is that we want to to limit the amount of code that can see and lock the Mutex here. (We’re using a blocking mutex close to async code, so we need to be careful.)
Fields
inner: Mutex<Inner<C>>The data, within a lock
(Danger: this uses a blocking mutex close to async code. This mutex must never be held while an await is happening.)
Implementations
Sourceimpl<C: AbstractChannelFactory> MgrState<C>
impl<C: AbstractChannelFactory> MgrState<C>
Sourcepub(crate) fn new(
builder: C,
config: ChannelConfig,
dormancy: Dormancy,
netparams: &NetParameters,
) -> Self
pub(crate) fn new( builder: C, config: ChannelConfig, dormancy: Dormancy, netparams: &NetParameters, ) -> Self
Create a new empty MgrState.
Sourcepub(crate) fn builder(&self) -> Cwhere
C: Clone,
pub(crate) fn builder(&self) -> Cwhere
C: Clone,
Return a copy of the builder stored in this state.
Sourcepub(crate) fn with_mut_builder<F>(&self, func: F)
pub(crate) fn with_mut_builder<F>(&self, func: F)
Sourcepub(crate) fn add_open(&self, channel: Arc<C::Channel>) -> Result<()>
pub(crate) fn add_open(&self, channel: Arc<C::Channel>) -> Result<()>
Add an open channel into our list.
Sourcepub(crate) fn request_channel(
&self,
target: &C::BuildSpec,
add_new_entry_if_not_found: bool,
) -> Result<Option<ChannelForTarget<C>>>
pub(crate) fn request_channel( &self, target: &C::BuildSpec, add_new_entry_if_not_found: bool, ) -> Result<Option<ChannelForTarget<C>>>
Request an open or pending channel to target. If add_new_entry_if_not_found is true and
an open or pending channel isn’t found, a new pending entry will be added and
ChannelForTarget::NewEntry will be returned. This is all done as part of the same method
so that all operations are performed under the same lock acquisition.
Sourcepub(crate) fn remove_pending_channel(
&self,
handle: PendingChannelHandle,
) -> Result<()>
pub(crate) fn remove_pending_channel( &self, handle: PendingChannelHandle, ) -> Result<()>
Remove the pending channel identified by its handle.
Sourcepub(crate) fn upgrade_pending_channel_to_open(
&self,
handle: PendingChannelHandle,
channel: Arc<C::Channel>,
) -> Result<()>
pub(crate) fn upgrade_pending_channel_to_open( &self, handle: PendingChannelHandle, channel: Arc<C::Channel>, ) -> Result<()>
Upgrade the pending channel identified by its handle by replacing it with a new open
channel.
Sourcepub(super) fn reconfigure_general(
&self,
new_config: Option<&ChannelConfig>,
new_dormancy: Option<Dormancy>,
netparams: Arc<dyn AsRef<NetParameters>>,
) -> StdResult<(), Bug>
pub(super) fn reconfigure_general( &self, new_config: Option<&ChannelConfig>, new_dormancy: Option<Dormancy>, netparams: Arc<dyn AsRef<NetParameters>>, ) -> StdResult<(), Bug>
Reconfigure all channels as necessary
(By reparameterizing channels as needed) This function will handle
- netdir update
- a reconfiguration
- dormancy
For new_config and new_dormancy, None means “no change to previous info”.
Note: As described in ChanMgr::set_create_request_handler(),
this doesn’t update the parameters for any CreateRequestHandler if one exists.
Sourcepub(crate) fn expire_channels(&self) -> Duration
pub(crate) fn expire_channels(&self) -> Duration
Expire all channels that have been unused for too long.
Return a Duration until the next time at which a channel could expire.
Sourcefn random_max_unused_duration() -> Duration
fn random_max_unused_duration() -> Duration
Helper: Return the default max unused duration for a channel.