struct NetParamsExtract {
nf_ito: [[IntegerMilliseconds<BoundedInt32<0, CHANNEL_PADDING_TIMEOUT_UPPER_BOUND>>; 2]; 2],
kist: KistParams,
}Expand description
Extract from a NetParameters which we need, conveniently organized for our processing
This type serves two functions at once:
-
Being a subset of the parameters, we can copy it out of the netdir, before we do more complex processing - and, in particular, before we obtain the lock on
inner(which we need to actually handle the update, because we need to combine information from the config with that from the netdir). -
Rather than four separate named fields for the padding options, it has arrays, so that it is easy to select the values without error-prone recapitulation of field names.
Fields
nf_ito: [[IntegerMilliseconds<BoundedInt32<0, CHANNEL_PADDING_TIMEOUT_UPPER_BOUND>>; 2]; 2]nf_ito_*, the padding timeout parameters from the netdir consensus
nf_ito[ 0=normal, 1=reduced ][ 0=low, 1=high ]
are nf_ito_{low,high}{,_reduced from NetParameters.
kist: KistParamsThe KIST parameters.
Implementations
Sourceimpl NetParamsExtract
impl NetParamsExtract
Sourcefn pad_low(&self, reduced: bool) -> IntegerMilliseconds<u32>
fn pad_low(&self, reduced: bool) -> IntegerMilliseconds<u32>
Return the padding timer parameter low end, for reduced-ness reduced, as a u32
Sourcefn pad_high(&self, reduced: bool) -> IntegerMilliseconds<u32>
fn pad_high(&self, reduced: bool) -> IntegerMilliseconds<u32>
Return the padding timer parameter high end, for reduced-ness reduced, as a u32