pub(crate) struct PendingEntry {
pub(crate) ids: RelayIds,
pub(crate) pending: Shared<Receiver<Result<()>>>,
pub(crate) unique_id: UniqPendingChanId,
}Expand description
An entry for a not-yet-build channel
Fields
ids: RelayIdsThe keys of the relay to which we’re trying to open a channel.
pending: Shared<Receiver<Result<()>>>A future we can clone and listen on to learn when this channel attempt is successful or failed.
This entry will be removed from the map (and possibly replaced with an
OpenEntry) before this future becomes ready.
unique_id: UniqPendingChanIdA unique ID that allows us to find this exact pending entry later.