Pending

Type Alias Pending 

type Pending = Shared<Receiver<Result<()>>>;
Type alias for a future that we wait on to see when a pending channel is done or failed.

Aliased Type

struct Pending { /* private fields */ }