pub fn settings_to_protocol(
vers: SocksVersion,
s: String,
) -> Result<Protocol, ProxyError>Expand description
Transform a string into a representation that can be sent as SOCKS authentication.
pub fn settings_to_protocol(
vers: SocksVersion,
s: String,
) -> Result<Protocol, ProxyError>Transform a string into a representation that can be sent as SOCKS authentication.