pub struct ChanBuilder<R, H: TransportImplHelper>{
runtime: R,
transport: H,
tls_connector: <R as TlsProvider<H::Stream>>::Connector,
tls_acceptor: Option<<R as TlsProvider<H::Stream>>::Acceptor>,
auth_material: Option<Arc<RelayChannelAuthMaterial>>,
my_addrs: Vec<SocketAddr>,
create_request_handler: Option<Arc<CreateRequestHandler>>,
}Expand description
TLS-based channel builder.
This is a separate type so that we can keep our channel management code network-agnostic.
It uses a provided TransportHelper type to make a connection (possibly
directly over TCP, and possibly over some other protocol). It then
negotiates TLS over that connection, and negotiates a Tor channel over that
TLS session.
This channel builder does not retry on failure, but it does implement a time-out.
Fields
runtime: RAsynchronous runtime for TLS, TCP, spawning, and timeouts.
transport: HThe transport object that we use to construct streams.
tls_connector: <R as TlsProvider<H::Stream>>::ConnectorObject to build TLS connections.
tls_acceptor: Option<<R as TlsProvider<H::Stream>>::Acceptor>Object to accept TLS connections.
auth_material: Option<Arc<RelayChannelAuthMaterial>>Relay authentication key material needed for relay channels.
my_addrs: Vec<SocketAddr>Our address(es) to use in the NETINFO cell.
create_request_handler: Option<Arc<CreateRequestHandler>>Provided to each new channel so that they can handle CREATE* requests.
Implementations
Sourceimpl<R, H: TransportImplHelper> ChanBuilder<R, H>
impl<R, H: TransportImplHelper> ChanBuilder<R, H>
Sourcepub fn new_client(runtime: R, transport: H) -> Self
pub fn new_client(runtime: R, transport: H) -> Self
Construct a new client specific ChanBuilder.
Sourcepub fn new_relay(
runtime: R,
transport: H,
auth_material: Arc<RelayChannelAuthMaterial>,
my_addrs: Vec<SocketAddr>,
create_request_handler: Option<Arc<CreateRequestHandler>>,
) -> Result<Self>
pub fn new_relay( runtime: R, transport: H, auth_material: Arc<RelayChannelAuthMaterial>, my_addrs: Vec<SocketAddr>, create_request_handler: Option<Arc<CreateRequestHandler>>, ) -> Result<Self>
Construct a new relay specific ChanBuilder.
Sourcepub fn rebuild_with_auth_material(
&self,
auth_material: Arc<RelayChannelAuthMaterial>,
) -> Result<Self>where
H: Clone,
pub fn rebuild_with_auth_material(
&self,
auth_material: Arc<RelayChannelAuthMaterial>,
) -> Result<Self>where
H: Clone,
Build a new ChanBuilder with the given auth_material,
cloning everything else.
This is needed because some relay keys rotate over time.
Sourcepub fn rebuild_with_create_request_handler(
&self,
handler: Arc<CreateRequestHandler>,
) -> Result<Self>where
H: Clone,
pub fn rebuild_with_create_request_handler(
&self,
handler: Arc<CreateRequestHandler>,
) -> Result<Self>where
H: Clone,
Build a new ChanBuilder with the given CREATE* request handler,
cloning everything else.
This is needed so that we can set the handler, which isn’t known when the builder is initially created.
Sourcefn outbound_chan_type(&self) -> ChannelType
fn outbound_chan_type(&self) -> ChannelType
Return the outbound channel type of this config.
The channel type is used when creating outbound channels. Relays always initiate channels as “relay initiator” while client and bridges behave like a “client initiator”.
Important: The wrong channel type is returned if this is called before with_identities()
is called.
Sourceimpl<R, H> ChanBuilder<R, H>
impl<R, H> ChanBuilder<R, H>
Sourceasync fn connect_no_timeout(
&self,
target: &OwnedChanTarget,
event_sender: Arc<Mutex<ChanMgrEventSender>>,
memquota: ChannelAccount,
) -> Result<Arc<Channel>>
async fn connect_no_timeout( &self, target: &OwnedChanTarget, event_sender: Arc<Mutex<ChanMgrEventSender>>, memquota: ChannelAccount, ) -> Result<Arc<Channel>>
Perform the work of connect_via_transport, but without enforcing a timeout.
Return a Channel on success.
Sourcefn validate_target_as_relay<CT>(&self, target: &CT) -> Result<()>where
CT: ChanTarget,
fn validate_target_as_relay<CT>(&self, target: &CT) -> Result<()>where
CT: ChanTarget,
Validate the given target as we (a relay) are attempting to connect to another relay.
Sourcefn validate_target<CT>(&self, target: &CT) -> Result<()>where
CT: ChanTarget,
fn validate_target<CT>(&self, target: &CT) -> Result<()>where
CT: ChanTarget,
Validate the given target as in if it is fine to connect to it.
There are several rules to follow based on the channel outbound type.
Sourceasync fn build_client_channel<T>(
&self,
tls: T,
peer_addr: MaybeSensitive<PeerAddr>,
target: &OwnedChanTarget,
peer_tls_cert: &[u8],
memquota: ChannelAccount,
event_sender: Arc<Mutex<ChanMgrEventSender>>,
) -> Result<Arc<Channel>>
async fn build_client_channel<T>( &self, tls: T, peer_addr: MaybeSensitive<PeerAddr>, target: &OwnedChanTarget, peer_tls_cert: &[u8], memquota: ChannelAccount, event_sender: Arc<Mutex<ChanMgrEventSender>>, ) -> Result<Arc<Channel>>
Build a client channel (always initiator).
This spawns the Reactor and return the tor_proto::channel::Channel.
Sourceasync fn build_relay_channel<T>(
&self,
tls: T,
peer_addr: MaybeSensitive<PeerAddr>,
target: &OwnedChanTarget,
peer_tls_cert: &[u8],
memquota: ChannelAccount,
event_sender: Arc<Mutex<ChanMgrEventSender>>,
) -> Result<Arc<Channel>>
async fn build_relay_channel<T>( &self, tls: T, peer_addr: MaybeSensitive<PeerAddr>, target: &OwnedChanTarget, peer_tls_cert: &[u8], memquota: ChannelAccount, event_sender: Arc<Mutex<ChanMgrEventSender>>, ) -> Result<Arc<Channel>>
Build a relay initiator channel.
This spawns the Reactor and return the tor_proto::channel::Channel.