pub(crate) fn open_channel_is_allowed<C: AbstractChannel>(
chan: &OpenEntry<C>,
target: &(impl HasRelayIds + HasChanMethod),
) -> boolExpand description
Returns true if the open channel is allowed to be used for a new channel request to the
target.