fn padding_parameters_builder(
reduced: bool,
netdir: &NetParamsExtract,
) -> Result<Option<ParametersBuilder>, &'static str>Expand description
Given a NetDirExtract and whether we’re reducing padding,
return a PaddingParametersBuilder
If the consensus specifies no padding, will return None;
but does not account for other reasons why padding might be enabled/disabled.
If Err, the string is a description of what is wrong with the parameters;
the caller should use PaddingParameters::Default.